@@ -103,7 +103,10 @@ def extract_categorized_keys_from_tree(
         raise ValueError(f"{tree_or_list} is neither a list nor a {Tree.__name__}")
     for condition_key in condition_keys:
         condition_node_type = derive_condition_node_type(condition_key)
-        if condition_node_type is ConditionNodeType.REQUIREMENT_CONSTRAINT:
+        if (
+            condition_node_type is ConditionNodeType.REQUIREMENT_CONSTRAINT
+            or condition_node_type is ConditionNodeType.REPEATABILITY_CONSTRAINT
+        ):
             result.requirement_constraint_keys.append(condition_key)
         elif condition_node_type is ConditionNodeType.HINT:
             result.hint_keys.append(condition_key)
